# Capture API

Output capture and redirection utilities.

## Context Managers

### capture_output

::: pyreprint.core.capture.capture_output

### redirect_to_file

::: pyreprint.core.capture.redirect_to_file

## Classes

### CapturedOutput

::: pyreprint.core.capture.CapturedOutput

### OutputTee

::: pyreprint.core.capture.OutputTee

### OutputBuffer

::: pyreprint.core.capture.OutputBuffer

